// java wrapper for vtkImageStencilAlgorithm object
//

package vtk;
import vtk.*;

public class vtkImageStencilAlgorithm extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOutput_2(vtkImageStencilData id0);
  public void SetOutput(vtkImageStencilData id0)
    { SetOutput_2(id0); }

  private native long GetOutput_3();
  public vtkImageStencilData GetOutput() {
    long temp = GetOutput_3();

    if (temp == 0) return null;
    return (vtkImageStencilData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkImageStencilAlgorithm() { super(); }

  public vtkImageStencilAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}
